@@ -12,15 +12,14 @@ def build_menu(parser, token):
     {% menu menu_name %}
     """
     try:
-        tag_name, menu_name, level = token.split_contents()        
+        tag_name, menu_name = token.split_contents()        
     except:
-        raise template.TemplateSyntaxError, "%r tag requires exactly two argument" % token.contents.split()[0]
-    return MenuObject(menu_name, level)
+        raise template.TemplateSyntaxError, "%r tag requires exactly one argument" % token.contents.split()[0]
+    return MenuObject(menu_name)
 
 class MenuObject(template.Node):
-    def __init__(self, menu_name, level):
+    def __init__(self, menu_name):
         self.menu_name = menu_name
-        self.level = level
 
     def render(self, context):        
         try:
@@ -33,9 +32,9 @@ class MenuObject(template.Node):
         except:
             pass
         
-        
-        m = Menu.objects.get(name_es="HORIZONTAL")
-        
-        print m
-        return m.render()
+        try:
+            m = Menu.objects.get(name=self.menu_name)
+            return m.render()
+        except Menu.DoesNotExist:
+            return "<!-- Menu not found -->"
 register.tag('menu', build_menu)
\ No newline at end of file
